@@ -35,17 +35,18 @@ using namespace QGit;
 
 class CheckListFileItem: public QCheckListItem {
 public:
-	CheckListFileItem(QListView* lv, SCRef file, SCRef status, SCRef index) :
+	CheckListFileItem(QListView* lv, SCRef file, const RevFile* f, int i) :
 	                  QCheckListItem(lv, file, QCheckListItem::CheckBox) {
 
-		setText(1, status);
-		setText(2, index);
+		bool inIndex = f->statusCmp(i, RevFile::IN_INDEX);
+		bool isNew = (f->statusCmp(i, RevFile::NEW) || f->statusCmp(i, RevFile::UNKNOWN));
+		setText(1, inIndex ? "In sync" : "Out of sync");
+		setOn(inIndex || !isNew);
 		myColor = Qt::black;
-
-		if (status == NEW || status == UNKNOWN)
+		if (isNew)
 			myColor = Qt::darkGreen;
 
-		else if (status == DELETED)
+		else if (f->statusCmp(i, RevFile::DELETED))
 			myColor = Qt::red;
 	}
 	virtual void paintCell(QPainter *p, const QColorGroup& cg, int column,
@@ -88,25 +89,17 @@ CommitImpl::CommitImpl(Git* g) : CommitBase(0, 0, Qt::WDestructiveClose), git(g)
 	QString msg;
 	QDir d;
 	if (d.exists(tmp))
-		git->readFromFile(tmp, msg);
+		readFromFile(tmp, msg);
 
 	// set-up files list
-	const RevFile* files = git->getFiles(ZERO_SHA);
-	for (uint i = 0; i < files->names.count(); ++i) {
+	const RevFile* f = git->getFiles(ZERO_SHA);
+	for (int i = 0; i < f->count(); ++i)
+		new CheckListFileItem(listViewFiles, git->filePath(*f, i), f, i);
 
-		SCRef lbl(files->isInIndex(i) ? "In sync" : "Out of sync");
-
-		CheckListFileItem* item = new CheckListFileItem(listViewFiles,
-		                          git->filePath(*files, i), files->getStatus(i), lbl);
-
-		item->setOn(!files->statusCmp(i, UNKNOWN));
-	}
 	// setup textEditMsg with default value
 	QString status(git->getDefCommitMsg());
-	if (status != "nothing to commit") { // FIXME: dirty hack!!
-		status.remove("\nnothing to commit", false);
-		msg.append(status);
-	}
+	status.prepend('\n').replace(QRegExp("\\n([^#])"), "\n#\\1"); // comment all the lines
+	msg.append(status.stripWhiteSpace());
 	textEditMsg->setText(msg);
 	textEditMsg->setCursorPosition(0, 0);
 
@@ -180,7 +173,7 @@ bool CommitImpl::checkFiles(SList selFiles) {
 bool CommitImpl::checkMsg(QString& msg) {
 
 	msg = textEditMsg->text();
-	msg.remove(QRegExp("\\n\\s*#[^\\n]*")); // strip comments
+	msg.remove(QRegExp("(^|\\n)\\s*#[^\\n]*")); // strip comments
 	msg.replace(QRegExp("[ \\t\\r\\f\\v]+\\n"), "\n"); // strip line trailing cruft
 	msg = msg.stripWhiteSpace();
 	if (msg.isEmpty()) {
@@ -328,7 +321,7 @@ void CommitImpl::textEditMsg_cursorPositionChanged(int para, int pos) {
 
 /*
 	Following code to compute cursor row and col position is
-	shameless taken from KEdit, indeed, it cames from
+	shameless taken from KEdit, indeed, it comes from
 	http://websvn.kde.org/branches/KDE/3.4/kdelibs/kdeui/keditcl1.cpp
 */
 void CommitImpl::computePosition(int line, int col, int &col_pos, int &line_pos) {
