@@ -17,15 +17,18 @@ class Git;
 class CommitImpl : public CommitBase {
 Q_OBJECT
 public:
-	CommitImpl(Git* git, bool* changesCommitted);
+	explicit CommitImpl(Git* git);
 	~CommitImpl();
 
+signals:
+	void changesCommitted(bool);
+
 public slots:
-	virtual void pushButtonOk_clicked();
-	virtual void pushButtonCancel_clicked();
-	virtual void pushButtonUpdateCache_clicked();
-	virtual void pushButtonSettings_clicked();
-	virtual void textEditMsg_cursorPositionChanged(int,int);
+	void pushButtonOk_clicked();
+	void pushButtonCancel_clicked();
+	void pushButtonUpdateCache_clicked();
+	void pushButtonSettings_clicked();
+	void textEditMsg_cursorPositionChanged(int,int);
 
 private slots:
 	void contextMenuPopup(QListViewItem*, const QPoint&, int);
@@ -39,7 +42,6 @@ private:
 	void computePosition(int para, int pos, int &col_pos, int &line_pos);
 
 	Git* git;
-	bool* commitOK;
 	QPopupMenu* contextMenu;
 	QString origMsg;
 	int CHECK_ALL;
