@@ -48,7 +48,7 @@ void ConsoleImpl::closeEvent(QCloseEvent* ce) {
 	Console::closeEvent(ce);
 }
 
-bool ConsoleImpl::start(const QString& cmd, const QString& cmdArgs) {
+bool ConsoleImpl::start(const QString& cmd, const QString& cmdArgs, QStringList* env) {
 
 	statusBar()->message("Executing \'" + name + "\' action...");
 
@@ -65,9 +65,9 @@ bool ConsoleImpl::start(const QString& cmd, const QString& cmdArgs) {
 
 	textLabelCmd->setText(txt);
 	if (tail.isEmpty())
-		proc = git->runAsync(txt, this);
+		proc = git->runAsync(txt, this, "", env);
 	else
-		proc = git->runAsScript(txt.append('\n'), this); // wrap in a script
+		proc = git->runAsScript(txt.append('\n'), this, "", env); // wrap in a script
 
 	if (proc.isNull())
 		deleteLater();
