@@ -19,7 +19,7 @@ class ConsoleImpl : public Console {
 Q_OBJECT
 public:
 	ConsoleImpl(const QString& nm, Git* g);
-	bool start(const QString& cmd,const QString& args);
+	bool start(const QString& cmd, const QString& args, QStringList* env);
 
 signals:
 	void customAction_exited(const QString& name);
