@@ -214,8 +214,11 @@ void DataLoader::on_cancel() {
 	if (!canceling) { // just once
 		canceling = true;
 		git->cancelProcess(proc);
-		if (!procPID.isEmpty())
+		if (!procPID.isEmpty()) {
+			git->errorReportingEnabled = false; // hide error when already terminated
 			git->run("kill " + procPID.stripWhiteSpace());
+			git->errorReportingEnabled = true;
+		}
 	}
 }
 
