@@ -32,22 +32,22 @@ bool ExceptionManager::isMatch(int value, int excp, const QString& context) {
 
 	bool match = (value == excp);
 	if (match) {
-		QString info("Catched exception \'" + descriptions[excp] +
+		QString info("Caught exception \'" + descriptions[excp] +
 		             "\' while in " + context);
 		qDebug(info);
 	}
 	return match;
 }
 
-void ExceptionManager::add(int excpId) {
+void ExceptionManager::add(int excpId, bool verbose) {
 // add a new exception in currentThrowableSet
 
 	// are prepended so to use a for loop starting
 	// from begin to find the latest. Exceptions are
 	// always added/removed from both totalThrowableSet
 	// and regionThrowableSet
-	totalThrowableSet.prepend(Exception(excpId));
-	regionThrowableSet.prepend(Exception(excpId));
+	totalThrowableSet.prepend(Exception(excpId, verbose));
+	regionThrowableSet.prepend(Exception(excpId, verbose));
 }
 
 void ExceptionManager::remove(int excpId) {
@@ -125,7 +125,7 @@ int ExceptionManager::saveThrowableSet() {
 	throwableSetMap.insert(currentRegionId, regionThrowableSet);
 	currentRegionId = ++regionId;
 
-	// we use this call to trigger a region bounduary crossing
+	// we use this call to trigger a region boundary crossing
 	// so we have to clear the new region throwables. We still
 	// have totalThrowableSet to catch any request.
 	regionThrowableSet.clear();
@@ -172,7 +172,8 @@ void ExceptionManager::throwPending() {
 		return;
 
 	int excpToThrow = (*it).excpId;
-	qDebug("Thrown exception \'%s\'", desc(excpToThrow).latin1());
+	if ((*it).verbose)
+		qDebug("Thrown exception \'%s\'", desc(excpToThrow).latin1());
 
 	throw excpToThrow;
 }
