@@ -30,7 +30,7 @@ const QString FileContent::HTML_FILE_END   = "</tt></pre>";
 
 class FileHighlighter : public QSyntaxHighlighter {
 public:
-	FileHighlighter(QTextEdit* te, FileContent* fc) : QSyntaxHighlighter(te), f(fc) {};
+	FileHighlighter(QTextEdit* te, FileContent* fc) : QSyntaxHighlighter(te), f(fc) {}
 	virtual int highlightParagraph(const QString& p, int) {
 
 		if (f->isHtmlSource)
@@ -61,7 +61,7 @@ FileContent::FileContent(Domain* dm, Git* g, QTextEdit* f) : d(dm), git(g), ft(f
 	st = &(d->st);
 
 	// init native types
-	isRangeFilterActive = isHtmlSource = false;
+	isRangeFilterActive = isHtmlSource = isAnnotationAppended = false;
 	isShowAnnotate = true;
 
 	rangeInfo = new RangeInfo();
@@ -99,7 +99,8 @@ void FileContent::clearText(bool emitSignal) {
 
 	git->cancelProcess(proc);
 	ft->clear();
-	fileRowData = fileProcessedData = halfLine = "";
+	fileProcessedData = halfLine = "";
+	fileRowData.resize(0);
 	isFileAvailable = isAnnotationAppended = false;
 	curLine = 1;
 	if (curAnn)
@@ -129,9 +130,11 @@ void FileContent::setShowAnnotate(bool b) {
 
 	// re-feed with file content processData()
 	saveScreenState();
-	const QString tmp(fileRowData);
+	const QByteArray tmp(fileRowData);
+	fileRowData.detach(); // QByteArray uses explicit sharing
 	clearText(false); // emitSignal = false
-	processData(tmp);
+	fileRowData = tmp;
+	processData(fileRowData);
 	on_eof(false); // print and call restoreScreenState()
 }
 
@@ -161,13 +164,12 @@ void FileContent::update(bool force) {
 	else
 		clearText();
 
-	if (!force)
-		lookupAnnotation(); // before file loading
+	lookupAnnotation(); // before file loading
 
 	if (isHtmlSource) // both calls bound on_eof() and on_procDataReady() slots
-		proc = git->getHighlightedFile(st->fileName(), st->sha(), this, NULL);
+		proc = git->getHighlightedFile(st->fileName(), st->sha(), this);
 	else
-		proc = git->getFile(st->fileName(), st->sha(), this, NULL); // non blocking
+		proc = git->getFile(st->fileName(), st->sha(), this); // non blocking
 
 	ss.isValid = false;
 	if (isRangeFilterActive)
@@ -433,15 +435,17 @@ void FileContent::on_annotateReady(Annotate* readyAnn, const QString& fileName,
 		emit annotationAvailable(true);
 }
 
-void FileContent::on_procDataReady(const QString& fileChunk) {
+void FileContent::on_procDataReady(const QByteArray& fileChunk) {
 
+	QGit::baAppend(fileRowData, fileChunk);
 	processData(fileChunk);
 }
 
 void FileContent::on_eof(bool emitSignal) {
 
-	if (!fileRowData.endsWith("\n"))
-		processData(QString("\n")); // fake a trailing new line
+	if (  !fileRowData.isEmpty()
+	    && fileRowData.at(fileRowData.size() - 1) != '\n')
+		processData('\n'); // flush pending half lines
 
 	ft->setText(fileProcessedData); // much faster then ft->append()
 	isFileAvailable = true;
@@ -452,9 +456,7 @@ void FileContent::on_eof(bool emitSignal) {
 		emit fileAvailable(true);
 }
 
-uint FileContent::processData(SCRef fileChunk) {
-
-	fileRowData.append(fileChunk);
+uint FileContent::processData(const QByteArray& fileChunk) {
 
 	QString newLines;
 	if (!QGit::stripPartialParaghraps(fileChunk, &newLines, &halfLine))
