@@ -464,43 +464,43 @@ const Rev* Git::revLookup(SCRef sha, const FileHistory* fh) const {
 	return r[sha];
 }
 
-bool Git::run(SCRef runCmd, QString* runOutput, QObject* receiver, SCRef buf) {
+bool Git::run(SCRef runCmd, QString* runOutput, QObject* receiver, SCRef buf, QStringList* env) {
 
 	if (!runOutput)
-		return run(NULL, runCmd, receiver, buf);
+		return run(NULL, runCmd, receiver, buf, env);
 
 	*runOutput = "";
 	QByteArray ba;
-	bool ret = run(&ba, runCmd, receiver, buf);
+	bool ret = run(&ba, runCmd, receiver, buf, env);
 	if (!ba.isEmpty())
 		runOutput->append(ba);
 
 	return ret;
 }
 
-bool Git::run(QByteArray* runOutput, SCRef runCmd, QObject* receiver, SCRef buf) {
+bool Git::run(QByteArray* runOutput, SCRef runCmd, QObject* receiver, SCRef buf, QStringList* env) {
 
 	MyProcess p(parent(), this, workDir, errorReportingEnabled);
-	return p.runSync(runCmd, runOutput, receiver, buf);
+	return p.runSync(runCmd, runOutput, receiver, buf, env);
 }
 
-MyProcess* Git::runAsync(SCRef runCmd, QObject* receiver, SCRef buf) {
+MyProcess* Git::runAsync(SCRef runCmd, QObject* receiver, SCRef buf, QStringList* env) {
 
 	MyProcess* p = new MyProcess(parent(), this, workDir, errorReportingEnabled);
-	if (!p->runAsync(runCmd, receiver, buf)) {
+	if (!p->runAsync(runCmd, receiver, buf, env)) {
 		delete p;
 		p = NULL;
 	}
 	return p; // auto-deleted when done
 }
 
-MyProcess* Git::runAsScript(SCRef runCmd, QObject* receiver, SCRef buf) {
+MyProcess* Git::runAsScript(SCRef runCmd, QObject* receiver, SCRef buf, QStringList* env) {
 
 	const QString scriptFile(workDir + "/qgit_script.sh");
 	if (!writeToFile(scriptFile, runCmd, true))
 		return NULL;
 
-	MyProcess* p = runAsync(scriptFile, receiver, buf);
+	MyProcess* p = runAsync(scriptFile, receiver, buf, env);
 	if (p)
 		connect(p, SIGNAL(eof()), this, SLOT(on_runAsScript_eof()));
 	return p;
@@ -598,11 +598,11 @@ MyProcess* Git::getDiff(SCRef sha, QObject* receiver, SCRef diffToSha, bool comb
 
 	QString runCmd;
 	if (sha != ZERO_SHA) {
-		runCmd = "git diff-tree -r --patch-with-stat ";
+		runCmd = "git diff-tree --no-color -r --patch-with-stat ";
 		runCmd.append(combined ? "-c " : "-C -m "); // TODO rename for combined
 		runCmd.append(diffToSha + " " + sha); // diffToSha could be empty
 	} else
-		runCmd = "git diff-index -r -m --patch-with-stat HEAD";
+		runCmd = "git diff-index --no-color -r -m --patch-with-stat HEAD";
 
 	return runAsync(runCmd, receiver);
 }
@@ -807,7 +807,7 @@ bool Git::isSameFiles(SCRef tree1Sha, SCRef tree2Sha) {
 	if (isParentOf(tree2Sha, tree1Sha))
 		return !isTreeModified(tree1Sha);
 
-	const QString runCmd("git diff-tree -r " + tree1Sha + " " + tree2Sha);
+	const QString runCmd("git diff-tree --no-color -r " + tree1Sha + " " + tree2Sha);
 	QString runOutput;
 	if (!run(runCmd, &runOutput))
 		return false;
@@ -1003,7 +1003,7 @@ const RevFile* Git::getAllMergeFiles(const Rev* r) {
 	if (rf)
 		return rf;
 
-	QString runCmd("git diff-tree -r -m -C " + r->sha()), runOutput;
+	QString runCmd("git diff-tree --no-color  -r -m -C " + r->sha()), runOutput;
 	if (!run(runCmd, &runOutput))
 		return NULL;
 
@@ -1024,7 +1024,7 @@ const RevFile* Git::getFiles(SCRef sha, SCRef diffToSha, bool allFiles, SCRef pa
 
 	if (!diffToSha.isEmpty() && (sha != ZERO_SHA)) {
 
-		QString runCmd("git diff-tree -r -m -C ");
+		QString runCmd("git diff-tree --no-color -r -m -C ");
 		runCmd.append(diffToSha + " " + sha);
 		if (!path.isEmpty())
 			runCmd.append(" " + path);
@@ -1045,7 +1045,7 @@ const RevFile* Git::getFiles(SCRef sha, SCRef diffToSha, bool allFiles, SCRef pa
 		dbs("ASSERT in Git::getFiles, ZERO_SHA not found");
 		return NULL;
 	}
-	QString runCmd("git diff-tree -r -c -C " + sha), runOutput;
+	QString runCmd("git diff-tree --no-color -r -c -C " + sha), runOutput;
 	if (!run(runCmd, &runOutput))
 		return NULL;
 
@@ -1091,7 +1091,7 @@ bool Git::getPatchFilter(SCRef exp, bool isRegExp, QMap<QString, bool>& shaMap)
 	if (buf.isEmpty())
 		return true;
 
-	QString runCmd("git diff-tree -r -s --stdin "), runOutput;
+	QString runCmd("git diff-tree --no-color -r -s --stdin "), runOutput;
 	if (isRegExp)
 		runCmd.append("--pickaxe-regex ");
 
@@ -1140,7 +1140,7 @@ bool Git::formatPatch(SCList shaList, SCRef dirPath, SCRef remoteDir) {
 	QSettings settings;
 	const QString FPArgs = settings.readEntry(APP_KEY + FPATCH_ARGS_KEY, "");
 
-	QString runCmd("git format-patch");
+	QString runCmd("git format-patch --no-color");
 	if (testFlag(NUMBERS_F) && !remote)
 		runCmd.append(" -n");
 
@@ -1250,7 +1250,7 @@ bool Git::commitFiles(SCList selFiles, SCRef msg) {
 bool Git::mkPatchFromIndex(SCRef msg, SCRef patchFile) {
 
 	QString runOutput;
-	if (!run("git diff-index --cached -p HEAD", &runOutput))
+	if (!run("git diff-index --no-color --cached -p HEAD", &runOutput))
 		return false;
 
 	const QString patch("Subject: " + msg + "\n---\n" + runOutput);
@@ -1399,18 +1399,10 @@ bool Git::stgPush(SCRef sha) {
 
 bool Git::stgPop(SCRef sha) {
 
-	QString top;
-	if (!run("stg top", &top))
-		return false;
-
 	const QStringList patch(getRefName(sha, APPLIED));
 	if (patch.count() != 1) {
 		dbp("ASSERT in Git::stgPop, found %1 patches instead of 1", patch.count());
 		return false;
 	}
-	if (patch.first() != top.stripWhiteSpace())
-		if (!run("stg pop " + quote(patch)))
-			return false;
-
-	return run("stg pop"); // finally remove selected one
+	return run("stg pop " + quote(patch));
 }
