@@ -178,10 +178,10 @@ private:
 	};
 	WorkingDirInfo _wd;
 
-	bool run(SCRef cmd, QString* out = NULL, QObject* rcv = NULL, SCRef buf = "");
-	bool run(QByteArray* runOutput, SCRef cmd, QObject* rcv = NULL, SCRef buf = "");
-	MyProcess* runAsync(SCRef cmd, QObject* rcv, SCRef buf = "");
-	MyProcess* runAsScript(SCRef cmd, QObject* rcv = NULL, SCRef buf = "");
+	bool run(SCRef cmd, QString* out = NULL, QObject* rcv = NULL, SCRef buf = "", QStringList* env = 0);
+	bool run(QByteArray* runOutput, SCRef cmd, QObject* rcv = NULL, SCRef buf = "", QStringList* env = 0);
+	MyProcess* runAsync(SCRef cmd, QObject* rcv, SCRef buf = "", QStringList* env = 0);
+	MyProcess* runAsScript(SCRef cmd, QObject* rcv = NULL, SCRef buf = "", QStringList* env = 0);
 	bool allProcessDeleted();
 	const QStringList getArgs(bool askForRange, bool* quit);
 	bool getRefs();
