@@ -294,12 +294,12 @@ void Git::getDiffIndex() {
 	if (!run("git status", &status)) // git status refreshes the index, run as first
 		return;
 
-	if (!run("git diff-index HEAD", &_wd.diffIndex))
+	if (!run("git diff-index --no-color HEAD", &_wd.diffIndex))
 		return;
 
 	// check for files already updated in cache, we will
 	// save this information in status third field
-	if (!run("git diff-index --cached HEAD", &_wd.diffIndexCached))
+	if (!run("git diff-index --no-color --cached HEAD", &_wd.diffIndexCached))
 		return;
 
 	// get any file not in tree
@@ -327,9 +327,15 @@ void Git::parseDiffFormatLine(RevFile& rf, SCRef line, int parNum) {
 
 	if (line[1] == ':') { // it's a combined merge
 
-		// TODO rename/copy is not supported for combined merges
+		/* For combined merges rename/copy information is useless
+		 * because nor the original file name, nor similarity info
+		 * is given, just the status tracks that in the left/right
+		 * branch a renamed/copy occurred (as example status could
+		 * be RM or MR). For visualization purposes we could consider
+		 * the file as modified
+		 */
 		appendFileName(rf, line.section('\t', -1));
-		setStatus(rf, line.section('\t', 0, 0).section(' ', -1, -1).left(1));
+		setStatus(rf, "M");
 		rf.mergeParent.append(parNum);
 	} else { // faster parsing in normal case
 
@@ -690,7 +696,7 @@ void Git::loadFileNames() {
 	}
 	if (!diffTreeBuf.isEmpty()) {
 		filesLoadingPending = filesLoadingCurSha = "";
-		const QString runCmd("git diff-tree -r -C --stdin");
+		const QString runCmd("git diff-tree --no-color -r -C --stdin");
 		runAsync(runCmd, this, diffTreeBuf);
 	}
 	indexTree();
