@@ -214,18 +214,18 @@ void MainImpl::getExternalDiffArgs(QStringList* args) {
 		const Rev* r = git->revLookup(rv->st.sha());
 		prevRevSha = (r && r->parentsCount() > 0) ? r->parent(0) : rv->st.sha();
 	}
-	QString fName1(curDir + "/" + rv->st.sha().left(6) + "_" + f.baseName(true));
-	QString fName2(curDir + "/" + prevRevSha.left(6) + "_" + f.baseName(true));
+	QString fName1(curDir + "/" + rv->st.sha().left(6) + "_" + f.fileName());
+	QString fName2(curDir + "/" + prevRevSha.left(6) + "_" + f.fileName());
 
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-	QString fileContent;
+	QByteArray fileContent;
 	git->getFile(rv->st.fileName(), rv->st.sha(), NULL, &fileContent);
-	if (!writeToFile(fName1, fileContent))
+	if (!writeToFile(fName1,  QString(fileContent)))
 		statusBar()->message("Unable to save " + fName1);
 
 	git->getFile(rv->st.fileName(), prevRevSha, NULL, &fileContent);
-	if (!writeToFile(fName2, fileContent))
+	if (!writeToFile(fName2, QString(fileContent)))
 		statusBar()->message("Unable to save " + fName2);
 
 	// get external diff viewer
@@ -476,6 +476,11 @@ void MainImpl::ActViewDiff_activated() {
 	}
 	rv->viewPatch(false);
 	ActViewDiffNewTab->setEnabled(true);
+
+	if (toolButtonFilter->isOn() || toolButtonBold->isOn()) {
+		bool isRegExp = (cmbSearch->currentItem() == 6);
+		emit highlightPatch(lineEditFilter->text(), isRegExp);
+	}
 }
 
 void MainImpl::ActViewDiffNewTab_activated() {
@@ -603,13 +608,14 @@ void MainImpl::filterList(bool isOn, bool onlyHighlight) {
 	}
 	bool evenLine = false;
 	int visibleCnt = 0;
+	QRegExp re(filter, false, true);
 	QListViewItem* firstItem = NULL;
 	QListView* lv = rv->tab()->listViewLog;
 	QListViewItemIterator it(lv);
 	while (it.current()) {
 		ListViewItem* item = static_cast<ListViewItem*>(it.current());
 		if (isOn) {
-			if (passFilter(item, filter, colNum, shaMap)) {
+			if (passFilter(item, re, colNum, shaMap)) {
 				if (onlyHighlight)
 					item->setHighlighted(true);
 				else {
@@ -655,7 +661,7 @@ void MainImpl::filterList(bool isOn, bool onlyHighlight) {
 	QApplication::postEvent(rv, new MessageEvent(msg));
 }
 
-bool MainImpl::passFilter(ListViewItem* item, SCRef filter, int colNum,
+bool MainImpl::passFilter(ListViewItem* item, const QRegExp& filter, int colNum,
                           const QMap<QString, bool>& shaMap) {
 
 	if (colNum == SHA_MAP_COL)
@@ -680,7 +686,7 @@ bool MainImpl::passFilter(ListViewItem* item, SCRef filter, int colNum,
 			field = item->sha();
 	}
 	// wildcard search, case insensitive
-	return (field.find(QRegExp(filter, false, true)) != -1);
+	return (field.find(filter) != -1);
 }
 
 void MainImpl::customEvent(QCustomEvent* e) {
@@ -1190,24 +1196,23 @@ void MainImpl::on_goRef_activated(int id) {
 
 void MainImpl::ActSplitView_activated() {
 
-	bool hide;
 	Domain* t;
 	switch (currentTabType(&t)) {
 	case TAB_REV: {
 		RevsView* rv = static_cast<RevsView*>(t);
-		hide = rv->tab()->textBrowserDesc->isVisible();
-		rv->tab()->textBrowserDesc->setHidden(hide);
-		rv->tab()->listBoxFiles->setHidden(hide); }
+		QWidget* w = rv->tab()->textBrowserDesc;
+		QSplitter* sp = static_cast<QSplitter*>(w->parent());
+		sp->setHidden(w->isVisible()); }
 		break;
 	case TAB_PATCH: {
 		PatchView* pv = static_cast<PatchView*>(t);
-		hide = pv->tab()->textBrowserDesc->isVisible();
-		pv->tab()->textBrowserDesc->setHidden(hide); }
+		QWidget* w = pv->tab()->textBrowserDesc;
+		w->setHidden(w->isVisible()); }
 		break;
 	case TAB_FILE: {
 		FileView* fv = static_cast<FileView*>(t);
-		hide = fv->tab()->histListView->isVisible();
-		fv->tab()->histListView->setHidden(hide); }
+		QWidget* w = fv->tab()->histListView;
+		w->setHidden(w->isVisible()); }
 		break;
 	default:
 		dbs("ASSERT in ActSplitView_activated: unknown current page");
@@ -1215,6 +1220,11 @@ void MainImpl::ActSplitView_activated() {
 	}
 }
 
+void MainImpl::ActShowDescHeader_toggled(bool) {
+
+	emit updateRevDesc();
+}
+
 void MainImpl::ActShowTree_toggled(bool b) {
 
 	if (b) {
@@ -1315,25 +1325,22 @@ void MainImpl::ActMailFormatPatch_activated() {
 	QApplication::restoreOverrideCursor();
 }
 
-bool MainImpl::askApplyPatchParameters(bool* commit, bool* fold) {
+bool MainImpl::askApplyPatchParameters(bool* workDirOnly, bool* fold) {
 
-	int ret = QMessageBox::question(this, "Apply Patch",
-	          "Do you want to commit or just to apply changes to "
-	          "working directory?", "&Cancel", "&Working dir", "&Commit", 0, 0);
-	if (ret == 0)
-		return false;
-
-	*commit = (ret == 2);
-	*fold = false;
-	if (*commit && git->isStGITStack()) {
+	int ret = 0;
+	if (!git->isStGITStack()) {
+		ret = QMessageBox::question(this, "Apply Patch",
+		      "Do you want to commit or just to apply changes to "
+		      "working directory?", "&Cancel", "&Working dir", "&Commit", 0, 0);
+		*workDirOnly = (ret == 1);
+		*fold = false;
+	} else {
 		ret = QMessageBox::question(this, "Apply Patch", "Do you want to "
 		      "import or fold the patch?", "&Cancel", "&Fold", "&Import", 0, 0);
-		if (ret == 0)
-			return false;
-
+		*workDirOnly = false;
 		*fold = (ret == 1);
 	}
-	return true;
+	return (ret != 0);
 }
 
 void MainImpl::ActMailApplyPatch_activated() {
@@ -1348,13 +1355,14 @@ void MainImpl::ActMailApplyPatch_activated() {
 	QFileInfo f(patchName);
 	settings.writeEntry(APP_KEY + FP_DIR_KEY, f.dirPath(true));
 
-	bool commit, fold;
-	if (!askApplyPatchParameters(&commit, &fold))
+	bool workDirOnly, fold;
+	if (!askApplyPatchParameters(&workDirOnly, &fold))
 		return;
 
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-	if (git->applyPatchFile(f.absFilePath(), commit, fold, !Git::optDragDrop) && !commit)
+	bool ok = git->applyPatchFile(f.absFilePath(), fold, !Git::optDragDrop);
+	if (workDirOnly && ok)
 		git->resetCommits(1);
 
 	QApplication::restoreOverrideCursor();
@@ -1455,7 +1463,21 @@ void MainImpl::on_customAction_activated(int id) {
 	connect(c, SIGNAL(customAction_exited(const QString&)),
 	        this, SLOT(on_customAction_exited(const QString&)));
 
-	if (c->start(cmd, cmdArgs))
+	QStringList selectedItems, selectedItemsReversed;
+	rv->listViewLog->getSelectedItems(selectedItems);
+
+	FOREACH_SL(it, selectedItems)
+		selectedItemsReversed.prepend(*it);
+
+        /* setup a bunch of environment variables to be
+         * freely used by the launched custom action
+         */
+	QStringList env;
+	env.append("QGIT_CURRENT_REVISION=" + lineEditSHA->text());
+	env.append("QGIT_SELECTED_REVISIONS=" + selectedItems.join(" "));
+	env.append("QGIT_SELECTED_REVISIONS_REVERSE=" + selectedItemsReversed.join(" "));
+
+	if (c->start(cmd, cmdArgs, &env))
 		c->show();
 }
 
