@@ -18,8 +18,8 @@ class MyProcess : public QProcess {
 Q_OBJECT
 public:
 	MyProcess(QObject *go, Git* g, const QString& wd, bool reportErrors);
-	bool runSync(SCRef runCmd, QByteArray* runOutput, QObject* rcv, SCRef buf);
-	bool runAsync(SCRef rc, QObject* rcv, SCRef buf);
+	bool runSync(SCRef runCmd, QByteArray* runOutput, QObject* rcv, SCRef buf, QStringList* env);
+	bool runAsync(SCRef rc, QObject* rcv, SCRef buf, QStringList* env);
 	static const QStringList splitArgList(SCRef cmd);
 
 signals:
@@ -33,10 +33,12 @@ private slots:
 	void on_readyReadStdout();
 	void on_readyReadStderr();
 	void on_processExited();
+	void on_launchFinished();
 
 private:
 	void setupSignals();
-	bool launchMe(SCRef runCmd, SCRef buf);
+	void appendSystemEnvironment(QStringList* env);
+	bool launchMe(SCRef runCmd, SCRef buf, QStringList* env);
 	void sendErrorMsg(bool notStarted = false);
 	static void restoreSpaces(QString& newCmd, SCRef sepChar);
 
@@ -51,6 +53,7 @@ private:
 	bool busy;
 	bool exitStatus;
 	bool async;
+	bool isLaunching;
 };
 
 #endif
